relax_orm_annotations library
Annotations-only export for use by code generators.
This file does NOT depend on Flutter or Drift, making it safe to import from build_runner and other pure-Dart contexts.
Classes
- Column
- Customizes how a field is stored in the database.
- Ignore
- Marks a field to be ignored by the ORM.
- PrimaryKey
- Marks a field as the primary key of the table.
- RelaxTable
- Marks a class as a RelaxORM table entity.
Constants
- ignore → const Ignore
- primaryKey → const PrimaryKey
- relaxTable → const RelaxTable